==> haskell-esqueleto-2.5.3.20180402-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: esqueleto
version: 2.6.0
id: esqueleto-2.6.0-D3DeLyuDzyC2cHomeaEcF2
key: esqueleto-2.6.0-D3DeLyuDzyC2cHomeaEcF2
license: BSD-3-Clause
copyright: (c) 2012-2016 Felipe Almeida Lessa
maintainer: cma@bitemyapp.com
author: Felipe Lessa
homepage: https://github.com/bitemyapp/esqueleto
synopsis: Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.
    .
    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)
    .
    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.
    .
    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.
category: Database
abi: 61f417f2b8f3166bd154d72a4cc68f8d
exposed: True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.SQLite
hidden-modules: Database.Esqueleto.Internal.PersistentImport
                Paths_esqueleto
import-dirs: /usr/lib/ghc-8.4.3/site-local/esqueleto-2.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/esqueleto-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/esqueleto-2.6.0
hs-libraries: HSesqueleto-2.6.0-D3DeLyuDzyC2cHomeaEcF2
depends:
    base-4.11.1.0 blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    bytestring-0.10.8.2 conduit-1.3.0.3-DaDndYTG6fcCpmR0FtgGkV
    monad-logger-0.3.28.5-3xACEIEYeQ5DBxS3ElwWhD
    persistent-2.8.2-4oHDgJFLXrAFxCX80ir0sy
    resourcet-1.2.1-9sz7rlxvCfi1vnYYgzfo9y
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 unliftio-0.2.7.0-5ooDSOY1GOzJVBwEYzFCbq
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             conduit-1.3.0.3-DaDndYTG6fcCpmR0FtgGkV=fd915ceae5687f6d9d6198682cb93cb3
             monad-logger-0.3.28.5-3xACEIEYeQ5DBxS3ElwWhD=43a94581f6600a0a160b751340ed04ab
             persistent-2.8.2-4oHDgJFLXrAFxCX80ir0sy=45ff22950f54d003ea8f7abe73f72bac
             resourcet-1.2.1-9sz7rlxvCfi1vnYYgzfo9y=09f9b32ede067fc2006d1c6f61df54b1
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unliftio-0.2.7.0-5ooDSOY1GOzJVBwEYzFCbq=7728e5e805f1a7d34363d997d0fc0ba8
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html: /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-esqueleto-2.5.3.20180402-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: esqueleto
version: 2.6.0
id: esqueleto-2.6.0-8GDKA3AhsrZDUmxdVBKnps
key: esqueleto-2.6.0-8GDKA3AhsrZDUmxdVBKnps
license: BSD-3-Clause
copyright: (c) 2012-2016 Felipe Almeida Lessa
maintainer: cma@bitemyapp.com
author: Felipe Lessa
homepage: https://github.com/bitemyapp/esqueleto
synopsis: Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.
    .
    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)
    .
    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.
    .
    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.
category: Database
abi: c60920158c82a187c96fd563944aa98b
exposed: True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.SQLite
hidden-modules: Database.Esqueleto.Internal.PersistentImport
                Paths_esqueleto
import-dirs: /usr/lib/ghc-8.4.3/site-local/esqueleto-2.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/esqueleto-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/esqueleto-2.6.0
hs-libraries: HSesqueleto-2.6.0-8GDKA3AhsrZDUmxdVBKnps
depends:
    base-4.11.1.0 blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    bytestring-0.10.8.2 conduit-1.3.0.3-CWvgMypgTVyHtfYib3PvqC
    monad-logger-0.3.28.5-JNfmspGcORAEkXtJKpnqjY
    persistent-2.8.2-2nykH2plZi2xjpelc3beR
    resourcet-1.2.1-HVkgWTomxbW9sgOb2d5u9e
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 unliftio-0.2.7.0-AFeB30DVisx8Fqrgr37gPq
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             conduit-1.3.0.3-CWvgMypgTVyHtfYib3PvqC=51cc6289d249cec67f7829e2212f3c47
             monad-logger-0.3.28.5-JNfmspGcORAEkXtJKpnqjY=4ad83bdb04be8c3a18f8cf2de2f50745
             persistent-2.8.2-2nykH2plZi2xjpelc3beR=85e444068587ed6ae66c31e784c28d64
             resourcet-1.2.1-HVkgWTomxbW9sgOb2d5u9e=08678aec30adcdae19c0b70973ad5f17
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unliftio-0.2.7.0-AFeB30DVisx8Fqrgr37gPq=0cac91530ef160a501800adfb27856f7
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html: /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
